from typing import Any

class Flash:
    def ioctl(self, *args) -> Any: ...
    def readblocks(self, *args) -> Any: ...
    def writeblocks(self, *args) -> Any: ...

class PIO:
    IN_HIGH: int
    IN_LOW: int
    IRQ_SM0: int
    IRQ_SM1: int
    IRQ_SM2: int
    IRQ_SM3: int
    JOIN_NONE: int
    JOIN_RX: int
    JOIN_TX: int
    OUT_HIGH: int
    OUT_LOW: int
    SHIFT_LEFT: int
    SHIFT_RIGHT: int
    def add_program(self, *args) -> Any: ...
    def irq(self, *args) -> Any: ...
    def remove_program(self, *args) -> Any: ...
    def state_machine(self, *args) -> Any: ...

class StateMachine:
    def exec(self, *args) -> Any: ...
    def get(self, *args) -> Any: ...
    def active(self, *args) -> Any: ...
    def init(self, *args) -> Any: ...
    def irq(self, *args) -> Any: ...
    def put(self, *args) -> Any: ...
    def restart(self, *args) -> Any: ...
    def rx_fifo(self, *args) -> Any: ...
    def tx_fifo(self, *args) -> Any: ...
