from typing import Any

def crc8(*args) -> Any: ...
def readbit(*args) -> Any: ...
def readbyte(*args) -> Any: ...
def reset(*args) -> Any: ...
def writebit(*args) -> Any: ...
def writebyte(*args) -> Any: ...
