from typing import Any

def __init__(*args) -> None: ...
def choice(*args) -> Any: ...
def getrandbits(*args) -> Any: ...
def randint(*args) -> Any: ...
def random(*args) -> Any: ...
def randrange(*args) -> Any: ...
def seed(*args) -> Any: ...
def uniform(*args) -> Any: ...
